@@ -86,7 +86,7 @@ class AbstractApplicationServlet(PasteWsgiServlet, Constants):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     #: The version number of this release. For example "6.2.0". Always in the
@@ -108,10 +108,10 @@ class AbstractApplicationServlet(PasteWsgiServlet, Constants):
     VERSION_BUILD = None
 
     #: Initialize version numbers from string replaced by build-script.
-    if '1.1.0' == '@' + 'VERSION' + '@':
+    if '1.1.1' == '@' + 'VERSION' + '@':
         VERSION = '9.9.9.INTERNAL-DEBUG-BUILD'
     else:
-        VERSION = '1.1.0'
+        VERSION = '1.1.1'
 
     digits = VERSION.split('.', 4)
     VERSION_MAJOR = int(digits[0])
@@ -717,7 +717,7 @@ class AbstractApplicationServlet(PasteWsgiServlet, Constants):
                 self.setHeader(response, 'Cache-Control',
                         'max-age=' + str(cacheTime / 1000))
                 self.setHeader(response, 'Expires',
-                        str(1000 * time.time() + cacheTime))
+                        str(1000 * time() + cacheTime))
                 # Required to apply caching in some Tomcats
                 self.setHeader(response, 'Pragma', 'cache')
 
@@ -1705,13 +1705,17 @@ class AbstractApplicationServlet(PasteWsgiServlet, Constants):
                     data store represented by the given URL.
         """
         reqURL = 'https://' if self.isSecure(request) else 'http://'
-        reqURL += self.getServerName(request)
-        if (self.isSecure(request) and self.getServerPort(request) == 443
-                or (not self.isSecure(request)
-                        and self.getServerPort(request) == 80)):
-            reqURL += ''
+        reqHost = request.environ().get('HTTP_HOST')
+        if reqHost:
+            reqURL += reqHost
         else:
-            reqURL += ':%d' % self.getServerPort(request)
+            reqURL += self.getServerName(request)
+            if (self.isSecure(request) and self.getServerPort(request) == 443
+                    or (not self.isSecure(request)
+                            and self.getServerPort(request) == 80)):
+                pass
+            else:
+                reqURL += ':%d' % self.getServerPort(request)
         reqURL += self.getRequestUri(request)
 
         # FIXME: implement include requests
