@@ -59,7 +59,7 @@ class AbstractField(AbstractComponent, field.IField,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self):
@@ -246,12 +246,13 @@ class AbstractField(AbstractComponent, field.IField,
         if self._dataSource is not None:
 
             # Gets the correct value from datasource
+            newValue = None
             try:
                 # Discards buffer by overwriting from datasource
                 if self.getType() == str:
                     newValue = str(self._dataSource)
                 else:
-                    self._dataSource.getValue()
+                    newValue = self._dataSource.getValue()
 
                 # If successful, remove set the buffering state to be ok
                 if self._currentBufferedSourceException is not None:
@@ -1087,7 +1088,7 @@ class IReadOnlyStatusChangeEvent(ComponentEvent, prop.IProperty,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self, source):
