@@ -18,7 +18,7 @@ items."""
 
 from collections import deque
 
-from muntjac.util import clsname
+from muntjac.util import clsname, OrderedSet
 from muntjac.terminal.key_mapper import KeyMapper
 from muntjac.terminal.gwt.client.mouse_event_details import MouseEventDetails
 
@@ -64,7 +64,7 @@ class Tree(AbstractSelect, container.IHierarchical, action.IContainer,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     CLIENT_WIDGET = None #ClientWidget(VTree, LoadStyle.EAGER)
@@ -427,7 +427,7 @@ class Tree(AbstractSelect, container.IHierarchical, action.IContainer,
                         TreeDragMode.ordinal(self._dragMode))
 
         # Initialize variables
-        actionSet = set()
+        actionSet = OrderedSet()
 
         # rendered selectedKeys
         selectedKeys = list()
@@ -993,7 +993,7 @@ class ExpandEvent(ComponentEvent):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self, source, expandedItemId):
@@ -1020,7 +1020,7 @@ class IExpandListener(object):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def nodeExpand(self, event):
@@ -1040,7 +1040,7 @@ class CollapseEvent(ComponentEvent):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self, source, collapsedItemId):
@@ -1067,7 +1067,7 @@ class ICollapseListener(object):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def nodeCollapse(self, event):
