@@ -28,13 +28,15 @@ from muntjac.terminal.stream_variable import \
 from muntjac.terminal.gwt.server.exceptions import \
     NoInputStreamException, NoOutputStreamException
 
+from muntjac.util import OrderedSet
+
 
 class IStartedListener(object):
     """Receives the events when the upload starts.
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def uploadStarted(self, event):
@@ -51,7 +53,7 @@ class IFinishedListener(object):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def uploadFinished(self, event):
@@ -68,7 +70,7 @@ class IFailedListener(object):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def uploadFailed(self, event):
@@ -85,7 +87,7 @@ class ISucceededListener(object):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def uploadSucceeded(self, event):
@@ -148,7 +150,7 @@ class Upload(AbstractComponent, IFocusable): #IComponent,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     CLIENT_WIDGET = None #ClientWidget(VUpload, LoadStyle.LAZY)
@@ -179,7 +181,7 @@ class Upload(AbstractComponent, IFocusable): #IComponent,
 
         #: ProgressListeners to which information about progress
         #  is sent during upload
-        self._progressListeners = set()
+        self._progressListeners = OrderedSet()
 
         self._progressCallbacks = dict()
 
@@ -682,7 +684,7 @@ class IReceiver(object):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def receiveUpload(self, filename, mimeType):
@@ -706,7 +708,7 @@ class FinishedEvent(ComponentEvent):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self, source, filename, MIMEType, length):
@@ -769,7 +771,7 @@ class FailedEvent(FinishedEvent):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self, source, filename, MIMEType, length, reason=None):
@@ -810,7 +812,7 @@ class SucceededEvent(FinishedEvent):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self, source, filename, MIMEType, length):
@@ -823,7 +825,7 @@ class StartedEvent(ComponentEvent):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     def __init__(self, source, filename, MIMEType, contentLength):
