@@ -33,6 +33,8 @@ from muntjac.event.field_events import \
     (IFocusNotifier, IBlurNotifier, FocusEvent, BlurEvent, IBlurListener,
     IFocusListener)
 
+from muntjac.util import OrderedSet
+
 
 class ICloseListener(object):
     """An interface used for listening to Window close events. Add the
@@ -104,7 +106,7 @@ class Window(Panel, IUriHandler, IParameterHandler, IFocusNotifier,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.1.0
+    @version: 1.1.1
     """
 
     CLIENT_WIDGET = None #ClientWidget(VWindow, LoadStyle.EAGER)
@@ -148,7 +150,7 @@ class Window(Panel, IUriHandler, IParameterHandler, IFocusNotifier,
 
         #: B{Application window only}. List of sub windows in this window.
         #  A sub window cannot have other sub windows.
-        self._subwindows = set()
+        self._subwindows = OrderedSet()
 
         #: B{Application window only}. Explicitly specified theme of this
         #  window or null if the application theme should be used.
